@@ -26,6 +26,16 @@
 #ifndef ANASTASIS_GTK_HANDLE_IDENTITY_CHANGED_H
 #define ANASTASIS_GTK_HANDLE_IDENTITY_CHANGED_H
 
+
+/**
+ * Mark widget for attribute with name @a name as problematic.
+ *
+ * @param name name of the attribute to highlight
+ */
+void
+AG_mark_invalid_input (const char *name);
+
+
 /**
  * Function called when the user changed anything about its identity.
  * Check whether the current input is valid and enables/disables the
