@@ -57,6 +57,48 @@ enum AG_ContinentsModelColumns
 };
 
 
+/**
+ * Columns of the secret_selection_liststore.
+ */
+enum AG_SecretSelectionModelColumns
+{
+  /**
+   * A gchararray.
+   */
+  AG_SSMC_PROVIDER_URL = 0,
+
+  /**
+   * A gint.
+   */
+  AG_SSMC_POLICY_VERSION = 1,
+
+  /**
+   * A gint.
+   */
+  AG_SSMC_ATTRIBUTE_MASK = 2,
+
+  /**
+   * A gchararray.
+   */
+  AG_SSMC_SECRET_NAME = 3,
+
+  /**
+   * A gchararray.
+   */
+  AG_SSMC_POLICY_DATE_STRING = 4,
+
+  /**
+   * A guint64.
+   */
+  AG_SSMC_POLICY_DATE_NUMERIC = 5,
+
+  /**
+   * A gpointer.
+   */
+  AG_SSMC_POLICY_PROVIDER_JSON = 6
+};
+
+
 /**
  * Columns of the currency_liststore.
  */
@@ -163,7 +205,7 @@ enum AG_ChallengeStatusModelColumns
 enum AG_ProviderModelColumns
 {
   /**
-   * A gchararray. Contains the providers base URL.
+   * A gchararray. Contains the provider's base URL.
    */
   AG_PMC_PROVIDER_URL = 0,
 
@@ -195,7 +237,13 @@ enum AG_ProviderModelColumns
   /**
    * A gboolean. false if this provider can be enabled.
    */
-  AG_PMC_PROVIDER_NOT_SENSITIVE = 6
+  AG_PMC_PROVIDER_NOT_SENSITIVE = 6,
+
+  /**
+   * A gchararray. Contains the provider's business name, if known,
+   * otherwise the provider's base URL.
+   */
+  AG_PMC_PROVIDER_NAME = 7,
 
 };
 
@@ -206,7 +254,7 @@ enum AG_ProviderModelColumns
 enum AG_BackupProviderColumns
 {
   /**
-   * A gchararray. 
+   * A gchararray.
    */
   AG_BPC_PROVIDER_URL = 0,
 
@@ -223,7 +271,12 @@ enum AG_BackupProviderColumns
   /**
    * A gboolean.
    */
-  AG_BPC_SUCCESS_FLAG = 3
+  AG_BPC_SUCCESS_FLAG = 3,
+
+  /**
+   * A gchararray.
+   */
+  AG_BPC_PROVIDER_NAME = 4
 
 };
 
@@ -336,7 +389,12 @@ enum AG_PolicyReviewModelColumns
   /**
    * A gboolean. True on lines representing solved challenges.
    */
-  AG_PRMC_WAS_SOLVED
+  AG_PRMC_WAS_SOLVED = 8,
+
+  /**
+   * Name of the provider (if known, otherwise the provider's URL).
+   */
+  AG_PRMC_PROVIDER_NAME = 9
 
 };
 
@@ -399,6 +457,13 @@ void
 AG_sensitive (const char *name);
 
 
+/**
+ * Make the 'next' button sensitive (and trigger it via 'Return').
+ */
+void
+AG_enable_next (void);
+
+
 /**
  * Make widget of the given @a name the focus.
  *
@@ -512,4 +577,17 @@ AG_setup_qrcode (GtkWidget *w,
                  size_t text_size);
 
 
+/**
+ * Expand base @a name of a widget based on the @a type to
+ * create the name of the widget with the data.
+ *
+ * @param name base name of the widget
+ * @param type type of the widget
+ * @return NULL on error
+ */
+char *
+AG_expand_name (const char *name,
+                const char *type);
+
+
 #endif
